import base64
import json
import os
import sys
import requests
import numpy as np
import argparse
from alibabacloud_ha3engine_vector.client import Client
from alibabacloud_ha3engine_vector.models import Config,PushDocumentsRequest

class DataPush:
    def __init__(self, args):
        self.input_data = args.input_data
        self.user_name = args.user_name
        self.password = args.password
        self.instance_id = args.instance_id
        self.table_name = self.instance_id + "_" + args.table_name
        self.bulk_size = int(args.bulk_size)
        config = Config(
            endpoint= f'{self.instance_id}.ha.aliyuncs.com',
            access_user_name=self.user_name,
            access_pass_word=self.password
        )
        self.client = Client(config)

    def push_data(self):
        #http://ha-cn-**********.ha.aliyuncs.com/update/$table_name/actions/bulk
        input_file = open(self.input_data, 'r')
        data = input_file.readlines()
        headers = {}
        count = 0
        print("Total Lines to Write:", len(data))
        for i in range(int(len(data)/self.bulk_size) + 1):
            bulk_data = [json.loads(j) for j in data[i*self.bulk_size: min(len(data), (i+1)*self.bulk_size)]]
            request = PushDocumentsRequest(headers=headers, body=bulk_data)
            response = self.client.push_documents(self.table_name, "pk", request)
            count = count + len(bulk_data)
            print("Written: ", count)

def main():
    parser = argparse.ArgumentParser()
    parser.add_argument("-i", "--input_data", help="input data", action="store", required=True)
    parser.add_argument("-t", "--table_name", help="table name", action="store", required=True)
    parser.add_argument("-u", "--user_name", help="user name", action="store", required=True)
    parser.add_argument("-p", "--password", help="password", action="store", required=True)
    parser.add_argument("-e", "--instance_id", help="instance id", action="store", required=True)
    parser.add_argument("-b", "--bulk_size", help="bulk size", action="store", default=10)

    args = parser.parse_args()
    process = DataPush(args)
    process.push_data()

if __name__ == '__main__':
    try:
        main()
        print("push data success!")
    except Exception as e:
        print(e)
        sys.exit(1)